******************************************************************************************************
* STEP | GENERATING DERIVED VARIABLES FROM THE BACKGROUND QUESTIONNAIRE & LITERACY ASSESSMENT DATA
*
*	DO-FILE 6: GENERATING AN ASSET INDEX FOR URBAN HOUSEHOLDS
*
* Based on T. Pave Sohnesen's do-file
* Created: April 25, 2013
* Last updated: May 21, 2014
******************************************************************************************************

/* 
This do-file generates an asset index for each of the following countries:
	- Bolivia
	- Laos
	- Sri Lanka
	- Vietnam
	- Yunnan
	- Colombia
	- Ukraine
NOTE: NO ASSET INDEX WAS GENERATED FOR COLOMBIA
	*/


global pathworkingdata


************************************************************* BOLIVIA *************************************************************
use "$pathworkingdata/STEP Bolivia_working.dta", clear
* GENERATE VARIABLES

*  Dwelling Characteristics

gen d_house=(m1b_q01==1)
gen d_indiv=(m1b_q01==2)
gen d_apart=(m1b_q01==3|m1b_q01==4)


gen w_cement=(m1b_q02==1)
gen w_brick=(m1b_q02==3)
gen w_wood=(m1b_q02==5)


gen r_metal=(m1b_q03==1)
gen r_concrete=(m1b_q03==3)
gen r_tile=(m1b_q03==4)
           
gen f_parquet=(m1b_q04==1)
gen f_wood=(m1b_q04==2)
gen f_concrete=(m1b_q04==3)
gen f_tile=(m1b_q04==4)
gen f_earth=(m1b_q04==5)
gen f_brick=(m1b_q04==6)

gen o_own=(m1b_q05==1|m1b_q05==2)
gen o_free=(m1b_q05==3|m1b_q05==4|m1b_q05==5)
gen o_rent=(m1b_q05==6)
gen o_anti=(m1b_q05==7)

*number of rooms
gen room_1=(m1b_q06==1)
gen room_2=(m1b_q06==2)
gen room_3=(m1b_q06==3)
gen room_4=(m1b_q06==4)
gen room_5=(m1b_q06==5)
gen room_6up=(m1b_q06>=6&m1b_q06~=.)

        
*drinking water
gen dw_pipe=(m1b_q08==1|m1b_q08==2)

*coocking
gen c_kitch=(m1b_q10==1)
gen c_house=(m1b_q10==2)

gen c_elec=(m1b_q11==1)
gen c_lpg=(m1b_q11==2)
gen c_gas=(m1b_q11==3)

*lightning
gen l_privat=(m1b_q12==2)
gen l_coop=(m1b_q12==3)

*toilet
gen to_flush=(m1b_q13==1)
gen to_pit=(m1b_q13==2)
gen to_shared=(m1b_q14==1)

*assets
gen a_cell1=(m1b_q15_1 ==1)
gen a_cell2=(m1b_q15_1a ==1)
gen a_phone=(m1b_q15_2 ==1)
gen a_radio=(m1b_q15_3 ==1)
gen a_tv=(m1b_q15_4 ==1)
gen a_refri=(m1b_q15_5 ==1)
gen a_wash=(m1b_q15_6 ==1)
gen a_airc=(m1b_q15_7 ==1)
gen a_comp=(m1b_q15_8 ==1)
gen a_int=(m1b_q15_9==1)
gen a_bicy=(m1b_q15_10==1)
gen a_motorc=(m1b_q15_11==1)
gen a_three=(m1b_q15_12==1)
gen a_car=(m1b_q15_13==1)
gen a_waterh=(m1b_q15_14==1)
gen a_micro=(m1b_q15_24==1)
gen a_printer=(m1b_q15_25==1)
gen a_cable=(m1b_q15_26==1)
gen a_ipod=(m1b_q15_27==1)

*Other ownerships
gen a2_sech=(m1b_q16_1 ==1)
gen a2_bank=(m1b_q16_2 ==1)
gen a2_ins=(m1b_q16_3 ==1)
gen a2_gard=(m1b_q16_4 ==1)
gen a2_agri=(m1b_q16_5 ==1)
gen a2_other=(m1b_q16_6 ==1)
gen a2_poul=(m1b_q16_7 ==1)

* Agr assets
gen ag_cow=(m1b_q17_1 >0 & m1b_q17_1 ~=.)
gen ag_sheep=(m1b_q17_2 >0 & m1b_q17_2 ~=.)
gen ag_pigs=(m1b_q17_3 >0 & m1b_q17_3 ~=.)
gen ag_hors=(m1b_q17_4 >0 & m1b_q17_4 ~=.)
gen ag_chick=(m1b_q17_5 >0 & m1b_q17_5 ~=.)
gen ag_rab=(m1b_q17_7 >0 & m1b_q17_7 ~=.)
gen ag_lam=(m1b_q17_8 >0 & m1b_q17_8 ~=.)

* books
 gen book_0=(m1b_q18==1)
 gen book_1=(m1b_q18==2)
 gen book_11=(m1b_q18==3)
 gen book_51=(m1b_q18==4)
 
***************
* ASSET INDEX *
***************
  
*Distribution of assets
sum a_* a2_* d_* r_* f_* o_* w_*  room_*  c_* l_* to_* ag_* dw_*

* Dropping highly skewed variables (mean <.02 or >.98) since all variables are indicator variables. 
drop a_three c_elec ag_cow ag_pig ag_hors ag_rab ag_lam 
  
    
*Overview of all asets 
factor a_* a2_* d_* r_* f_* w_* o_* room_*  c_* l_* to_* ag_* dw_*  [aw=W_FinSPwt], mineigen(1) 
rotate, varimax
predict all_assets
alpha a_* a2_* d_* r_* f_* w_* o_* room_* c_* l_* to_* ag_* dw_* 
/*Comments: All asset have loading factors as could ve expected, 16 eigen values have a value over 1 ///
first vector explains 15.20 %. a Cronbachs alpha of 0.8566 indicates strong underlying measure */
 
**** A look at "types" of assets 
*Dwelling
factor d_* r_* f_* w_* o_* room_* c_* l_* to_*  dw_*  [aw=W_FinSPwt], mineigen(1)
rotate, varimax
predict dwelling
alpha d_* r_* f_* w_* o_* room_* c_* l_* to_* dw_*
/* Dwelling characteristics have 14 eigen values with more than 1, and the first one explains 16.35% of variation ///
A Cronbach's alpha of 0.7868 indicates moderate underlying measure*/
 
* Assets 1
factor a_*  [aw=W_FinSPwt], mineigen(1)
rotate, varimax
predict asset1
alpha a_*  
/* Primary Assets have only 1 eigen value with more than one and it explains 87.26% of variation ///
A Cronbach's alpha of 0.8343 indicates strong underlying measure*/
 
* Assets 2
factor a2_*   [aw=W_FinSPwt], mineigen(1)
/*No factors retained*/
*rotate, varimax
factor a2_* [aw=W_FinSPwt]
predict asset2
alpha a2_*
/*Assets2 do not jointly seem to represent underlying definition of wealth with 0 egenvalues over 1, 
an index was estimated with all the variables. Cronbach's alpha is 0.3988 indicating low underlying measure */

* Agriculture
factor ag_*  [aw=W_FinSPwt], mineigen(1) 
/*No factors retained*/
*rotate, varimax
factor ag_*
predict agri
alpha ag_*
/* Agriculture do not jointly seem to represent underlying definition of wealth with 0 egenvalues over 1 
an index was estimated with all the variables. Cronbach's alpha is 0.2295 indicating low underlying measure */

pwcorr all_assets dwelling asset1 asset2 agri [aw=W_FinSPwt] ,sig

*asset2 and aggriculture asset s have low correlation to overal asset index

*Dropping agriculture related
drop ag_sheep ag_chick a2_agri a2_poul

*Dropping assets not relates to overall assets (<0.1 of factor loading, before rotation): 
drop a_cell2 

*Dropping secondary assets not related to overall assets (<0.1 of factor loading, before rotation):
drop a2_other  

*Dropping dwelling characteristics not related to overall assets (<0.1 of factor loading, before rotation):
drop f_wood o_anti room_3 c_lpg c_gas dw_pipe

***** Asset Index with remaining variables *********
factor a_* a2_* d_* r_* f_* w_* o_* room_* c_* l_* to_* [aw=W_FinSPwt], mineigen(1) 
predict asset_index
alpha  a_* a2_* d_* r_* f_* w_* o_* room_* c_* l_* to_*
/* Cronbach's Alpha: 0.8674.*/

*kdensity asset_index [aw=W_FinSPwt]
  * strong indication of an underlying index with a Cronbachs a of 0.8808
	xtile asset_q=asset_index [aw=W_FinSPwt] , nq(5)
 
 keep asset_q  country asset_index hhn cluster W_FinSPwt
 sort cluster hhn
 save "$pathworkingdata/Temp.dta", replace

use "$pathworkingdata/STEP Bolivia_working.dta",clear
sort cluster hhn
merge cluster hhn using "$pathworkingdata/Temp.dta"
assert _merge==3
drop _merge
label var asset_index "Asset Wealth Index"
label var asset_q "Asset Wealth Index Quintiles"

compress
sort cluster hhn
save "$pathworkingdata/STEP Bolivia_working.dta", replace

******************************************************** END OF BOLIVIA ********************************************************

************************************************************* COLOMBIA *************************************************************
use "$pathworkingdata/STEP Colombia_working.dta", clear
* GENERATE VARIABLES

*  Dwelling Characteristics

gen d_house=(m1b_q01==1)
gen d_indiv=(m1b_q01==2)
gen d_apart=(m1b_q01==3|m1b_q01==4)


gen w_bricks=(m1b_q02==1)
gen w_adobe=(m1b_q02==2)
gen w_stone=(m1b_q02==3)
gen w_palm=(m1b_q02==4)
gen w_wood=(m1b_q02==5)


gen r_metal=(m1b_q03==1)
gen r_concrete=(m1b_q03==3)
gen r_tile=(m1b_q03==4)
           
gen f_parquet=(m1b_q04==1)
gen f_wood=(m1b_q04==2)
gen f_concrete=(m1b_q04==3)
gen f_tile=(m1b_q04==4)
gen f_earth=(m1b_q04==5)
gen f_brick=(m1b_q04==6)

drop f_ajus_ii-f_ajus_per

gen o_own=(m1b_q05==1|m1b_q05==2)
gen o_free=(m1b_q05==3|m1b_q05==4|m1b_q05==5)
gen o_rent=(m1b_q05==6)


*number of rooms
gen room_1=(m1b_q06==1)
gen room_2=(m1b_q06==2)
gen room_3=(m1b_q06==3)
gen room_4=(m1b_q06==4)
gen room_5=(m1b_q06==5)
gen room_6up=(m1b_q06>=6&m1b_q06~=.)

        
*drinking water
gen dw_pipe=(m1b_q08==1|m1b_q08==2)
gen dw_bottl=(m1b_q08==9)

*coocking
gen c_kitch=(m1b_q10==1)
gen c_house=(m1b_q10==2)


gen c_elec=(m1b_q11==1)
gen c_lpg=(m1b_q11==2)
gen c_gas=(m1b_q11==3)

*lightning
gen l_pub=(m1b_q12==1)
gen l_privat=(m1b_q12==2)

*toilet
gen to_flush=(m1b_q13==1)

gen to_shared=(m1b_q14==1)

*assets
gen a_cell1=(m1b_q15_22 ==1 | m1b_q15_23==1)
gen a_phone=(m1b_q15_2 ==1)
gen a_radio=(m1b_q15_3 ==1 | m1b_q15_3a==1)
gen a_tv=(m1b_q15_4 ==1)
gen a_refri=(m1b_q15_5 ==1)
gen a_wash=(m1b_q15_6 ==1)
gen a_airc=(m1b_q15_7 ==1|m1b_q15_7a==1)
gen a_comp=(m1b_q15_8 ==1)
gen a_int=(m1b_q15_9==1)
gen a_bicy=(m1b_q15_10==1)
gen a_motorc=(m1b_q15_11==1)
gen a_three=(m1b_q15_12==1)
gen a_car=(m1b_q15_13==1)
gen a_waterh=(m1b_q15_14==1)
gen a_micro=(m1b_q15_18==1)
gen a_printer=(m1b_q15_19==1)
gen a_cable=(m1b_q15_20==1)
gen a_ipod=(m1b_q15_21==1)

*Other ownerships
gen a2_sech=(m1b_q16_1 ==1)
gen a2_bank=(m1b_q16_2 ==1)
gen a2_ins=(m1b_q16_3 ==1)
gen a2_gard=(m1b_q16_4 ==1)
gen a2_agri=(m1b_q16_5 ==1)
gen a2_other=(m1b_q16_6 ==1)
gen a2_poul=(m1b_q16_7 ==1)

* books
 gen book_0=(m1b_q18==1)
 gen book_1=(m1b_q18==2)
 gen book_11=(m1b_q18==3)
 gen book_51=(m1b_q18==4)
 
***************
* ASSET INDEX *
***************
  
*Distribution of assets
sum a_* a2_* d_* r_* f_* o_* w_*  room_*  c_* l_* to_* dw_*

* Dropping highly skewed variables (mean <.02 or >.98) since all variables are indicator variables. 
drop a_three a2_agri a2_other f_parquet f_earth f_brick w_adobe w_stone w_palm w_wood l_privat to_flush dw_bottl 
  
    
*Overview of all asets 
factor a_* a2_* d_* r_* f_* w_* o_* room_*  c_* l_* to_* dw_*  [aw=W_FinSPwt], mineigen(1) 
rotate, varimax
predict all_assets
alpha a_* a2_* d_* r_* f_* w_* o_* room_* c_* l_* to_* dw_* 
/*Comments: All asset have loading factors as could ve expected, 12 eigen values have a value over 1 ///
first vector explains 19.66 %. a Cronbachs alpha of 0.8031 indicates strong underlying measure */
 
**** A look at "types" of assets 
*Dwelling
factor d_* r_* f_* w_* o_* room_* c_* l_* to_*  dw_*  [aw=W_FinSPwt], mineigen(1)
rotate, varimax
predict dwelling
alpha d_* r_* f_* w_* o_* room_* c_* l_* to_* dw_*
/* Dwelling characteristics have 11 eigen values with more than 1, and the first one explains 14.15% of variation ///
A Cronbach's alpha of 0.6361 indicates moderate underlying measure*/
 
* Assets 1
factor a_*  [aw=W_FinSPwt], mineigen(1)
rotate, varimax
predict asset1
alpha a_*  
/* Primary Assets have only 1 eigen value with more than one and it explains 88.54% of variation ///
A Cronbach's alpha of 0.7771 indicates moderate underlying measure*/
 
* Assets 2
factor a2_*   [aw=W_FinSPwt], mineigen(1)
/*No factors retained*/
*rotate, varimax
factor a2_* [aw=W_FinSPwt]
predict asset2
alpha a2_*
/*Assets2 do not jointly seem to represent underlying definition of wealth with 0 egenvalues over 1, 
an index was estimated with all the variables. Cronbach's alpha is 0.3863 indicating low underlying measure */

* Agriculture*
*factor ag_*  [aw=W_FinSPwt], mineigen(1) 
/*No factors retained*/
*rotate, varimax
*factor ag_*
*predict agri
*alpha ag_*

pwcorr all_assets dwelling asset1 asset2 [aw=W_FinSPwt] ,sig

*asset2 and aggriculture asset s have low correlation to overal asset index


*Dropping agriculture related
drop a2_poul

*Dropping assets not relates to overall assets (<0.1 of factor loading, before rotation): 
/* None*/

*Dropping secondary assets not related to overall assets (<0.1 of factor loading, before rotation):
/* None*/

*Dropping dwelling characteristics not related to overall assets (<0.1 of factor loading, before rotation):
drop d_apart r_tile f_wood w_bricks c_elec l_pub dw_pipe

***** Asset Index with remaining variables *********
factor a_* a2_* d_* r_* f_* o_* room_* c_*  to_* [aw=W_FinSPwt], mineigen(1) 
predict asset_index
alpha  a_* a2_* d_* r_* f_* o_* room_* c_*  to_*
/* Cronbach's Alpha: 0.8218.*/

*kdensity asset_index [aw=W_FinSPwt]
	xtile asset_q=asset_index [aw=W_FinSPwt] , nq(5)
 
 keep asset_q  country asset_index hhn cluster W_FinSPwt
 sort cluster hhn
 save "$pathworkingdata/Temp.dta", replace

use "$pathworkingdata/STEP Colombia_working.dta",clear
sort cluster hhn
merge cluster hhn using "$pathworkingdata/Temp.dta"
assert _merge==3
drop _merge
label var asset_index "Asset Wealth Index"
label var asset_q "Asset Wealth Index Quintiles"

compress
sort cluster hhn
save "$pathworkingdata/STEP Colombia_working.dta", replace

******************************************************** END OF COLOMBIA ********************************************************


************************************************************* LAOS *************************************************************
use "$pathworkingdata/STEP Laos_working.dta", clear
* ONLY FOR URBAN HHS
keep if urban==1
keep cluster hhn W* m1b*

*************************
* GENERATE VARIABLES

*  Dwelling Characteristics
gen d_house=(m1b_q01==1)
gen d_indiv=(m1b_q01==2)
gen d_apart=(m1b_q01==3|m1b_q01==4)
gen d_temp=(m1b_q01==4)

gen w_cinderblock=(m1b_q02==9)
gen w_brick=(m1b_q02==1)
gen w_wood=(m1b_q02==7)
gen w_mud=(m1b_q02==6)

gen r_metal=(m1b_q03==2)
gen r_tile=(m1b_q03==5) 

gen f_parquet=(m1b_q04==1)
gen f_wood=(m1b_q04==2)
gen f_concrete=(m1b_q04==3)
gen f_tile=(m1b_q04==4)
gen f_earth=(m1b_q04==5)
gen f_bamboo=(m1b_q04==7)

gen o_own=(m1b_q05==1|m1b_q05==2)
gen o_free=(m1b_q05==3|m1b_q05==4|m1b_q05==5)
gen o_rent=(m1b_q05==6)


*number of rooms
gen room_1=(m1b_q06==1)
gen room_2=(m1b_q06==2)
gen room_3=(m1b_q06==3)
gen room_4=(m1b_q06==4)
gen room_5=(m1b_q06==5)
gen room_6up=(m1b_q06>=6&m1b_q06~=.)

*drinking water
gen dw_pipe=(m1b_q08==1|m1b_q08==2|m1b_q08==3)
gen dw_well=(m1b_q08==4)
gen dw_surf=(m1b_q08==5|m1b_q08==6|m1b_q08==7)
gen dw_bottl=(m1b_q08==9)

*coocking location
gen c_kitch=(m1b_q10==1)
gen c_house=(m1b_q10==2)
gen c_sepb=(m1b_q10==3)
gen c_out=(m1b_q10==4)

*energy coocking
gen c_elec=(m1b_q11==1)
gen c_lpg=(m1b_q11==2)
*gen c_gas=(m1b_q11==3)
gen c_char=(m1b_q11==5)
gen c_wood=(m1b_q11==7)

 
*lightning
gen l_pub=(m1b_q12==1)


*toilet
gen to_flush=(m1b_q13==2)
gen to_pit=(m1b_q13==3)
gen to_no=(m1b_q13==11)

gen to_shared=(m1b_q14==1)


*assets
gen a_cell1=(m1b_q15_1 ==1)
gen a_phone=(m1b_q15_2 ==1)
gen a_radio=(m1b_q15_3 ==1)
gen a_tv=(m1b_q15_4 ==1)
gen a_refri=(m1b_q15_5 ==1)
gen a_wash=(m1b_q15_6 ==1)
gen a_airc=(m1b_q15_7 ==1)
gen a_comp=(m1b_q15_8 ==1)
gen a_int=(m1b_q15_9==1)
gen a_bicy=(m1b_q15_10==1)
gen a_motorc=(m1b_q15_11==1)
gen a_three=(m1b_q15_12==1)
gen a_car=(m1b_q15_13==1)
gen a_waterh=(m1b_q15_14==1)
gen a_boat1=(m1b_q15_16==1)
gen a_boat2=(m1b_q15_17==1)
gen a_sew=(m1b_q15_18==1)
gen a_vacu=(m1b_q15_19==1)
gen a_cooker=(m1b_q15_20==1)
gen a_camera=(m1b_q15_21==1)
gen a_trac=(m1b_q15_22==1)
gen a_trac2=(m1b_q15_23==1)
gen a_fan=(m1b_q15_24==1)
gen a_waterp=(m1b_q15_25==1)
gen a_cable=(m1b_q15_26==1)
gen a_dvd=(m1b_q15_27==1)

*Other ownerships
gen a2_sech=(m1b_q16_1 ==1)
gen a2_bank=(m1b_q16_2 ==1)
gen a2_ins=(m1b_q16_3 ==1)
gen a2_gard=(m1b_q16_4 ==1)
gen a2_agri=(m1b_q16_5 ==1)
gen a2_other=(m1b_q16_6 ==1)
gen a2_poul=(m1b_q16_7 ==1)

* Agr assets
gen ag_cow=(m1b_q17_1 >0 & m1b_q17_1 ~=.)
gen ag_horse=(m1b_q17_2 >0 & m1b_q17_2 ~=.)
gen ag_goat=(m1b_q17_4 >0 & m1b_q17_4 ~=.)
gen ag_sheep=(m1b_q17_5 >0 & m1b_q17_5 ~=.)
gen ag_chick=(m1b_q17_6 >0 & m1b_q17_6 ~=.)
gen ag_pig=(m1b_q17_7 >0 & m1b_q17_7 ~=.)

***************
* ASSET INDEX *
***************

*Distribution of assets
sum a_* a2_* d_* r_* f_* o_* w_*  room_*  c_* l_* to_* ag_* dw_*

* Dropping highly skewed variables (mean <.02 or >.98) since all variables are indicator variables. 
drop a_trac2 d_indiv d_apart d_temp f_parquet f_bamboo o_free o_rent ag_horse ag_sheep

*Overview of all asets 
factor a_* a2_* d_* r_* f_* w_* o_* room_*  l_* c_*  to_* ag_* dw_*  [aw=W_FinSPwt], mineigen(1) 
rotate, varimax
predict all_assets
alpha a_* a2_* d_* r_* f_* w_* o_* room_* l_* c_*  to_* ag_* dw_* 
/*Comments: All asset have loading factors as could ve expected, 16 eigen values have a value over 1 ///
first vector explains 24.05%. a Cronbachs alpha of 0.8951 indicates strong underlying measure */
 
**** A look at "types" of assets 
*Dwelling
factor d_* r_* f_* w_* o_* room_* l_* c_* to_*  dw_*  [aw=W_FinSPwt], mineigen(1)
rotate, varimax
predict dwelling
alpha d_* r_* f_* w_* o_* room_* l_* c_* to_* dw_*
/* Dwelling characteristics have 13 eigen values with more than 1, and the first one explains 18.58% of variation ///
A Cronbach's alpha of 0.8121 indicates strong underlying measure*/
 
* Assets 1
factor a_*  [aw=W_FinSPwt], mineigen(1)
rotate, varimax
predict asset1
alpha a_*  
/* Primary Assets have only 2 eigen value with more than one and the first one explains 69.17% of variation ///
A Cronbach's alpha of 0.8054 indicates strong underlying measure*/
 
* Assets 2
factor a2_*   [aw=W_FinSPwt], mineigen(1)
/*No factors retained*/
*rotate, varimax
factor a2_* [aw=W_FinSPwt]
predict asset2
alpha a2_*
/*Assets2 do not jointly seem to represent underlying definition of wealth with 0 egenvalues over 1 
an index was estimated with all the variables. Cronbach's alpha is 0.4188 indicating low underlying measure */

* Agriculture
factor ag_*  [aw=W_FinSPwt], mineigen(1) 
/*No factors retained*/
*rotate, varimax
factor ag_*
predict agri
alpha ag_*
/* Agriculture do not jointly seem to represent underlying definition of wealth with 0 egenvalues over 1 
an index was estimated with all the variables. Cronbach's alpha is 0.5157 indicating weak underlying measure */

pwcorr all_assets dwelling asset1 asset2 agri [aw=W_FinSPwt] ,sig
/* All seem to correlate well*/


*Dropping agriculture related
drop ag_* a2_agri a2_poul

*Dropping assets not relates to overall assets (<0.1 of factor loading, before rotation): 
drop a_three a_boat* a_waterp 

*Dropping secondary assets not related to overall assets (<0.1 of factor loading, before rotation):
/* none*/

*Dropping dwelling characteristics not related to overall assets (<0.1 of factor loading, before rotation):
drop d_house f_concrete o_own c_house c_out to_shared

***** Asset Index with remaining variables *********
factor a_* a2_* r_* f_* w_* room_* l_* c_* to_* dw_* [aw=W_FinSPwt], mineigen(1) 
predict asset_index
alpha  a_* a2_* r_* f_* w_* room_* l_* c_* to_* dw_*
/* Cronbach's Alpha: 0.8978.*/

*kdensity asset_index [aw=W_FinSPwt]

xtile asset_q=asset_index [aw=W_FinSPwt] , nq(5)
 
 keep asset_q  asset_index hhn cluster W_FinSPwt
 save "$pathworkingdata/Temp.dta", replace

 
use "$pathworkingdata/STEP Laos_working.dta",clear
sort cluster hhn
merge cluster hhn using "$pathworkingdata/Temp.dta"
/*tab _merge

     _merge |      Freq.     Percent        Cum.
------------+-----------------------------------
          1 |        813       28.58       28.58	RURAL: NO ASSET INDEX
          3 |      2,032       71.42      100.00	URBAN: OK
------------+-----------------------------------
      Total |      2,845      100.00

*/
drop _merge
label var asset_index "Asset Wealth Index"
label var asset_q "Asset Wealth Index Quintiles"

compress
sort cluster hhn
save "$pathworkingdata/STEP Laos_working.dta", replace


******************************************************** END OF LAOS ********************************************************



************************************************************* SRI LANKA *************************************************************
use "$pathworkingdata/STEP Sri Lanka_working.dta", clear
* ONLY FOR URBAN HHS
keep if urban==1
keep cluster hhn W* m1b*

*************************
* GENERATE VARIABLES

*  Dwelling Characteristics

gen d_house=(m1b_q01==1)
gen d_indiv=(m1b_q01==2)
gen d_apart=(m1b_q01==3|m1b_q04)
gen d_temp=(m1b_q01==5)

gen w_concrete=(m1b_q02==3)
gen w_brick=(m1b_q02==1)
gen w_metal=(m1b_q02==7)
gen w_cabo=(m1b_q02==2)



gen r_metal=(m1b_q03==4)
gen r_asbest=(m1b_q03==2)
gen r_tile=(m1b_q03==1)
gen r_concre=(m1b_q03==3)
 
gen f_cement=(m1b_q04==1)
gen f_tile=(m1b_q04==2)

gen o_own=(m1b_q05==1|m1b_q05==2)
gen o_free=(m1b_q05==3|m1b_q05==4|m1b_q05==5)
gen o_rent=(m1b_q05==6)
    
*number of rooms
gen room_1=(m1b_q06==1)
gen room_2=(m1b_q06==2)
gen room_3=(m1b_q06==3)
gen room_4=(m1b_q06==4)
gen room_5=(m1b_q06==5)
gen room_6up=(m1b_q06>=6&m1b_q06~=.)

*drinking water
gen dw_pipe=(m1b_q08==5|m1b_q08==6)
gen dw_well=(m1b_q08==1|m1b_q08==2|m1b_q08==3|m1b_q08==4)

*coocking location
gen c_kitch=(m1b_q10==1)
gen c_house=(m1b_q10==2)
gen c_sepb=(m1b_q10==3)
gen c_out=(m1b_q10==4)
 
*energy coocking
gen c_elec=(m1b_q11==1)
gen c_lpg=(m1b_q11==2)
gen c_wood=(m1b_q11==7)
gen c_kersone=(m1b_q11==6)


*lightning
gen l_pub=(m1b_q12==1)
gen l_comu=(m1b_q12==2)
gen l_gen=(m1b_q12==5)
gen l_kero=(m1b_q12==8)

*toilet
gen to_flush =(m1b_q13==1)
gen to_pit=(m1b_q13==2)

gen to_shared=(m1b_q14==1)


*assets
gen a_cell1=(m1b_q15_1 ==1)
gen a_phone=(m1b_q15_2 ==1)
gen a_radio=(m1b_q15_3 ==1)
gen a_sew=(m1b_q15_4 ==1)
gen a_waterh=(m1b_q15_5 ==1)
gen a_cooker=(m1b_q15_6 ==1)
gen a_fan=(m1b_q15_7 ==1)
gen a_airc=(m1b_q15_8 ==1)
gen a_tv=(m1b_q15_9==1)
gen a_refri=(m1b_q15_11==1)
gen a_wash=(m1b_q15_12==1)
gen a_micro=(m1b_q15_14==1)
gen a_comp=(m1b_q15_15==1)
gen a_int=(m1b_q15_16==1)
gen a_bicy=(m1b_q15_17==1)
gen a_motorc=(m1b_q15_18==1)
gen a_threew=(m1b_q15_19==1)
gen a_car=(m1b_q15_20==1)
gen a_cart=(m1b_q15_23==1)
gen a_boat1=(m1b_q15_24==1)
gen a_boat2=(m1b_q15_25==1)

*Other ownerships
gen a2_sech=(m1b_q16_1 ==1)
gen a2_bank=(m1b_q16_2 ==1)
gen a2_ins=(m1b_q16_3 ==1)
gen a2_gard=(m1b_q16_4 ==1)
gen a2_agri=(m1b_q16_5 ==1)
gen a2_other=(m1b_q16_6 ==1)
gen a2_poul=(m1b_q16_7 ==1)

* Agr assets
gen ag_cow=(m1b_q17_1 >0 & m1b_q17_1 ~=.)
gen ag_donk=(m1b_q17_2 >0 & m1b_q17_2 ~=.)
gen ag_pig=(m1b_q17_3 >0 & m1b_q17_3 ~=.)
gen ag_goat=(m1b_q17_4 >0 & m1b_q17_4 ~=.)
gen ag_poultry=(m1b_q17_5 >0 & m1b_q17_5 ~=.)
gen ag_oth=(m1b_q17_6 >0 & m1b_q17_6 ~=.)

  
***************
* ASSET INDEX *
***************
  
*Distribution of assets
sum a_* a2_* d_* r_* f_* o_* w_*  room_*  c_* l_* to_* ag_* dw_*

* Dropping highly skewed variables (mean <.02 or >.98) since all variables are indicator variables. 
drop a_cart a_boat1 a_boat2 d_apart d_temp c_sepb l_comu l_gen l_kero ag_cow ag_donk ag_pig ag_goat ag_oth
    
*Overview of all asets 
factor a_* a2_* d_* r_* f_* w_* o_* room_*  c_*  l_* to_*  dw_* ag_* [w=W_FinSPwt], mineigen(1) 
rotate, varimax
predict all_assets
alpha a_* a2_* d_* r_* f_* w_* o_* room_* c_* l_*  to_* dw_*  ag_*
/*Comments: All asset have loading factors as could ve expected, 16 eigen values have a value over 1 ///
first vector explains 15.82%. a Cronbachs alpha of 0.8062 indicates strong underlying measure */
 
**** A look at "types" of assets 
*Dwelling
factor d_* r_* f_* w_* o_* room_* c_* l_* to_*  dw_*  [aw=W_FinSPwt], mineigen(1)
rotate, varimax
predict dwelling
alpha d_* r_* f_* w_* o_* room_* c_* l_* to_* dw_*
/* Dwelling characteristics have 12 eigen values with more than 1, and the first one explains 11.84% of variation ///
A Cronbach's alpha of 0.5831 indicates weak underlying measure*/
 
* Assets 1
factor a_*  [aw=W_FinSPwt], mineigen(1)
rotate, varimax
predict asset1
alpha a_*  
/* Primary Assets have only 1 eigen value with more than one and it explains 82.53% of variation ///
A Cronbach's alpha of 0.7456 indicates moderate underlying measure*/
 
* Assets 2
factor a2_*   [aw=W_FinSPwt], mineigen(1)
/*No factors retained*/
*rotate, varimax
factor a2_* [aw=W_FinSPwt]
predict asset2
alpha a2_*
/*Assets2 do not jointly seem to represent underlying definition of wealth with 0 egenvalues over 1 
an index was estimated with all the variables. Cronbach's alpha is 0.4278 indicating low underlying measure */

* Agriculture
*factor ag_*  [aw=W_FinSPwt], mineigen(1) 
/*Not enough vars*/
*rotate, varimax
*factor ag_*
*predict agri
*alpha ag_*

pwcorr all_assets dwelling asset1 asset2  [aw=W_FinSPwt] ,sig

*dwelling and secondary assets have low correlation to overal asset index


*Dropping agriculture related
drop ag_poultry a2_agri a2_poul

*Dropping assets not relates to overall assets (<0.1 of factor loading, before rotation): 
drop a_airc a_bicy a_three

*Dropping secondary assets not related to overall assets (<0.1 of factor loading, before rotation):
/*None*/  

*Dropping dwelling characteristics not related to overall assets (<0.1 of factor loading, before rotation):
drop d_house d_indiv r_asbest r_tile w_cabo o_rent c_elec to_flush to_pit 
 
***** Asset Index with remaining variables *********
factor a_* a2_* r_* f_* w_* o_* room_* l_* c_* to_* dw_* [aw=W_FinSPwt], mineigen(1) 
predict asset_index
alpha  a_* a2_* r_* f_* w_* o_* room_* l_* c_* to_* dw_*
/* Cronbach's Alpha: 0.8280.*/

*kdensity asset_index [aw=W_FinSPwt]
 xtile asset_q=asset_index [aw=W_FinSPwt] , nq(5)
  
 keep asset_q  asset_index hhn cluster W_FinSPwt
 save "$pathworkingdata/Temp.dta", replace

 
use "$pathworkingdata/STEP Sri Lanka_working.dta",clear
sort cluster hhn
merge cluster hhn using "$pathworkingdata/Temp.dta"
tab _merge
/*
     _merge |      Freq.     Percent        Cum.
------------+-----------------------------------
          1 |      1,793       59.99       59.99	RURAL: NO ASSET INDEX
          3 |      1,196       40.01      100.00	URBAN: OK
------------+-----------------------------------
      Total |      2,989      100.00
*/
drop _merge
label var asset_index "Asset Wealth Index"
label var asset_q "Asset Wealth Index Quintiles"
compress
sort cluster hhn
save "$pathworkingdata/STEP Sri Lanka_working.dta", replace

******************************************************** END OF SRI LANKA ********************************************************


******************************************************** VIETNAM ********************************************************
use "$pathworkingdata/STEP Vietnam_working.dta", clear

*************************
* GENERATE VARIABLES *
**********************

*  Dwelling Characteristics

gen d_house=(m1b_q01==1)
gen d_indiv=(m1b_q01==2)
gen d_apart=(m1b_q01==3|m1b_q01==4)
gen d_temp=(m1b_q01==4)

gen w_brick=(m1b_q02==13)

gen r_metal=(m1b_q03==6)
gen r_cala=(m1b_q03==7)
gen r_tile=(m1b_q03==8)
gen r_cement=(m1b_q03==9)

gen f_marble=(m1b_q04==9)
gen f_concrete=(m1b_q04==7)
gen f_tile=(m1b_q04==6)

gen o_own=(m1b_q05==1|m1b_q05==2)
gen o_free=(m1b_q05==3|m1b_q05==4|m1b_q05==5)
gen o_rent=(m1b_q05==6)

*number of rooms
gen room_1=(m1b_q06==1)
gen room_2=(m1b_q06==2)
gen room_3=(m1b_q06==3)
gen room_4=(m1b_q06==4)
gen room_5=(m1b_q06==5)
gen room_6up=(m1b_q06>=6&m1b_q06~=.)

*drinking water
gen dw_pipe=(m1b_q08==1|m1b_q08==2)
gen dw_well=(m1b_q08==3|m1b_q08==4)
gen dw_bottl=(m1b_q08==9)
    
*coocking location
gen c_kitch=(m1b_q10==1)
gen c_house=(m1b_q10==2)
gen c_sepb=(m1b_q10==3)
gen c_out=(m1b_q10==4)
 
*energy coocking
gen c_elec=(m1b_q11==1)
gen c_lpg=(m1b_q11==2)
gen c_char=(m1b_q11==5)
gen c_kersone=(m1b_q11==6)

*lightning
gen l_pub=(m1b_q12==1)
gen l_privat=(m1b_q12==2)
gen l_kero=(m1b_q12==4)

*toilet
gen to_flush =(m1b_q13==1)
gen to_pit=(m1b_q13==2)

gen to_shared=(m1b_q14==1)


*assets
gen a_cell1=(m1b_q15_1 ==1)
gen a_phone=(m1b_q15_2 ==1)
gen a_radio=(m1b_q15_3 ==1)
gen a_tv=(m1b_q15_4 ==1)
gen a_refri=(m1b_q15_5 ==1)
gen a_wash=(m1b_q15_6 ==1)
gen a_airc=(m1b_q15_7 ==1)
gen a_comp=(m1b_q15_8 ==1)
gen a_int=(m1b_q15_9==1)
gen a_bicy=(m1b_q15_10==1)
gen a_motorc=(m1b_q15_11==1)
gen a_three=(m1b_q15_12==1)
gen a_car=(m1b_q15_13==1)
gen a_waterh=(m1b_q15_14==1)
gen a_cart=(m1b_q15_15==1)
gen a_boat1=(m1b_q15_16==1)
gen a_boat2=(m1b_q15_17==1)
gen a_micro=(m1b_q15_18==1)


*Other ownerships
gen a2_sech=(m1b_q16_1 ==1)
gen a2_bank=(m1b_q16_2 ==1)
gen a2_ins=(m1b_q16_3 ==1)
gen a2_gard=(m1b_q16_4 ==1)
gen a2_agri=(m1b_q16_5 ==1)
gen a2_other=(m1b_q16_6 ==1)
gen a2_poul=(m1b_q16_7 ==1)



* Agr assets
gen ag_cow=(m1b_q17_1 >0 & m1b_q17_1 ~=.)
gen ag_buff=(m1b_q17_2 >0 & m1b_q17_2 ~=.)
gen ag_pig=(m1b_q17_3 >0 & m1b_q17_3 ~=.)
gen ag_chick=(m1b_q17_4 >0 & m1b_q17_4 ~=.)
gen ag_duck=(m1b_q17_5 >0 & m1b_q17_5 ~=.)
gen ag_goose=(m1b_q17_6 >0 & m1b_q17_6 ~=.)
gen ag_oth=(m1b_q17_7 >0 & m1b_q17_7 ~=.)


***************
* ASSET INDEX *
***************
  
*Distribution of assets
sum a_* a2_* d_* r_* f_* o_* w_*  room_*  c_* l_* to_* ag_* dw_*

* Dropping highly skewed variables (mean <.02 or >.98) since all variables are indicator variables. 
drop a_cart a_boat* c_out c_kersone l_pub l_privat l_kero ag_cow ag_buff ag_pig ag_duck ag_goose
    
*Overview of all asets 
factor a_* a2_* d_* r_* f_* w_* o_* room_*  c_*  to_* ag_* dw_*  [aw=W_FinSPwt], mineigen(1) 
rotate, varimax
predict all_assets
alpha a_* a2_* d_* r_* f_* w_* o_* room_* c_*  to_* ag_* dw_* 
/*Comments: All asset have loading factors as could ve expected, 16 eigen values have a value over 1 ///
first vector explains 16.97%. a Cronbachs alpha of 0.8267 indicates strong underlying measure */
 
**** A look at "types" of assets 
*Dwelling
factor d_* r_* f_* w_* o_* room_* c_* to_*  dw_*  [aw=W_FinSPwt], mineigen(1)
rotate, varimax
predict dwelling
alpha d_* r_* f_* w_* o_* room_* c_* to_* dw_*
/* Dwelling characteristics have 14 eigen values with more than 1, and the first one explains 12.99% of variation ///
A Cronbach's alpha of 0.7058 indicates moderate underlying measure*/
 
* Assets 1
factor a_*  [aw=W_FinSPwt], mineigen(1)
rotate, varimax
predict asset1
alpha a_*  
/* Primary Assets have only 1 eigen value with more than one and it explains 83.54% of variation ///
A Cronbach's alpha of 0.7701 indicates strong underlying measure*/
 
* Assets 2
factor a2_*   [aw=W_FinSPwt], mineigen(1)
/*No factors retained*/
*rotate, varimax
factor a2_* [aw=W_FinSPwt]
predict asset2
alpha a2_*
/*Assets2 do not jointly seem to represent underlying definition of wealth with 0 egenvalues over 1 
an index was estimated with all the variables. Cronbach's alpha is 0.3756 indicating low underlying measure */

* Agriculture
factor ag_*  [aw=W_FinSPwt], mineigen(1) 
/*No factors retained*/
*rotate, varimax
factor ag_*
predict agri
alpha ag_*
/* Agriculture do not jointly seem to represent underlying definition of wealth with 0 egenvalues over 1 
an index was estimated with all the variables. Cronbach's alpha is 0.3724 indicating low underlying measure */

pwcorr all_assets dwelling asset1 asset2 agri [aw=W_FinSPwt] ,sig

*dwelling and agriculture assets have low correlation to overal asset index


*Dropping agriculture related
drop ag_chick ag_oth a2_agri a2_poul

*Dropping assets not relates to overall assets (<0.1 of factor loading, before rotation): 
drop a_bicy a_three 

*Dropping secondary assets not related to overall assets (<0.1 of factor loading, before rotation):
drop a2_sech a2_gard  

*Dropping dwelling characteristics not related to overall assets (<0.1 of factor loading, before rotation):
drop d_house d_apart d_temp c_elec room_3
 
***** Asset Index with remaining variables *********
factor a_* a2_* d_* r_* f_* w_* o_* room_* c_* to_* dw_* [aw=W_FinSPwt], mineigen(1) 
predict asset_index
alpha  a_* a2_* d_* r_* f_* w_* o_* room_* c_* to_* dw_*
/* Cronbach's Alpha: 0.8509.*/

*kdensity asset_index [aw=W_FinSPwt]

xtile asset_q=asset_index [aw=W_FinSPwt] , nq(5)
 
keep asset_q  country asset_index hhn cluster W_FinSPwt
 save "$pathworkingdata/Temp.dta", replace

use "$pathworkingdata/STEP Vietnam_working.dta",clear
sort cluster hhn
merge cluster hhn using "$pathworkingdata/Temp.dta"
assert _merge==3
drop _merge
label var asset_index "Asset Wealth Index"
label var asset_q "Asset Wealth Index Quintiles"
compress
sort cluster hhn
save "$pathworkingdata/STEP Vietnam_working.dta", replace

******************************************************** END OF VIETNAM ********************************************************



******************************************************** YUNNAN ********************************************************
use "$pathworkingdata/STEP Yunnan_working.dta", clear
*************************
*  Dwelling Characteristics

gen d_house=(m1b_q01==1)
gen d_apart=(m1b_q01==2|m1b_q01==3|m1b_q01==4)

gen w_brick=(m1b_q02==1)
gen w_concr=(m1b_q02==3)

gen r_concre=(m1b_q03==4)

gen f_parquet=(m1b_q04==1)
gen f_wood=(m1b_q04==2)
gen f_concrete=(m1b_q04==3)
gen f_tile=(m1b_q04==4)

gen o_own=(m1b_q05==1|m1b_q05==2)
gen o_free=(m1b_q05==3|m1b_q05==4|m1b_q05==5)
gen o_rent=(m1b_q05==6)
tab m1b_q05


*number of rooms
gen room_1=(m1b_q06==1)
gen room_2=(m1b_q06==2)
gen room_3=(m1b_q06==3)
gen room_4=(m1b_q06==4)
gen room_5=(m1b_q06==5)
gen room_6up=(m1b_q06>=6&m1b_q06~=.)

*drinking water
gen dw_pipe=(m1b_q08==1|m1b_q08==2)
gen dw_bottl=(m1b_q08==9)

*coocking location
gen c_kitch=(m1b_q10==1)
gen c_house=(m1b_q10==2)
 
*energy coocking
gen c_elec=(m1b_q11==1)
gen c_lpg=(m1b_q11==2)
gen c_pipeg=(m1b_q11==10)

*Lighting
gen l_pub=(m1b_q12==1)

*toilet
gen to_flush =(m1b_q13==1| m1b_q13==2)
gen to_lat=(m1b_q13==3)

gen to_shared=(m1b_q14==2|m1b_q14==3)


*assets
gen a_cell1=(m1b_q15_1 ==1)
gen a_phone=(m1b_q15_2 ==1)
gen a_radio=(m1b_q15_3 ==1)
gen a_tv=(m1b_q15_4 ==1)
gen a_refri=(m1b_q15_5 ==1)
gen a_wash=(m1b_q15_6 ==1)
gen a_airc=(m1b_q15_7 ==1)
gen a_comp=(m1b_q15_8 ==1)
gen a_int=(m1b_q15_9==1)
gen a_bicy=(m1b_q15_10==1)
gen a_three=(m1b_q15_11==1)
gen a_elec_car=(m1b_q15_12==1)
gen a_motorc=(m1b_q15_13==1|m1b_q15_14==1)
gen a_car=(m1b_q15_15==1)
gen a_waterh=(m1b_q15_16==1)
gen a_camera=(m1b_q15_17==1)
gen a_vcamera=(m1b_q15_18==1)
gen a_dvd=(m1b_q15_19==1)
gen a_micro=(m1b_q15_20==1)
gen a_cooker=(m1b_q15_21==1)

*Other ownerships
gen a2_sech=(m1b_q16_1 ==1)
gen a2_bank=(m1b_q16_2 ==1)
gen a2_ins=(m1b_q16_3 ==1)
gen a2_gard=(m1b_q16_4 ==1)
gen a2_agri=(m1b_q16_5 ==1)
gen a2_other=(m1b_q16_6 ==1)
gen a2_poul=(m1b_q16_7 ==1)


* Agr assets
gen ag_cow=(m1b_q17_1 >0 & m1b_q17_1 ~=.)
gen ag_horse=(m1b_q17_2 >0 & m1b_q17_2 ~=.)
gen ag_pig=(m1b_q17_3 >0 & m1b_q17_3 ~=.)
gen ag_goat=(m1b_q17_4 >0 & m1b_q17_4 ~=.)
gen ag_chick=(m1b_q17_5 >0 & m1b_q17_5 ~=.)

 
***************
* ASSET INDEX *
***************

*Distribution of assets
sum a_* a2_* d_* r_* f_* o_* w_*  room_*  c_* l_* to_* ag_* dw_*

* Dropping highly skewed variables (mean <.02 or >.98) since all variables are indicator variables. 
drop a_cell1 a_tv a2_other a2_poul w_concr l_pub ag_cow ag_horse ag_pig ag_goat ag_chick

*Overview of all asets 
factor a_* a2_* d_* r_* f_* w_* o_* room_*  c_*  to_* dw_*  [aw=W_FinSPwt], mineigen(1) 
rotate, varimax
predict all_assets
alpha a_* a2_* d_* r_* f_* w_* o_* room_* c_*  to_* dw_* 
/*Comments: All asset have loading factors as could ve expected, 12 eigen values have a value over 1 ///
first vector explains 17.54%. a Cronbachs alpha of 0.7702 indicates strong underlying measure */
 
**** A look at "types" of assets 
*Dwelling
factor d_* r_* f_* w_* o_* room_*  c_* to_*  dw_*  [aw=W_FinSPwt], mineigen(1)
rotate, varimax
predict dwelling
alpha d_* r_* f_* w_* o_* room_*  c_* to_* dw_*
/* Dwelling characteristics have 10 eigen values with more than 1, and the first one explains 15.94% of variation ///
A Cronbach's alpha of 0.6616 indicates weak underlying measure*/
 
* Assets 1
factor a_*  [aw=W_FinSPwt], mineigen(1)
rotate, varimax
predict asset1
alpha a_*  
/* Primary Assets have only 1 eigen value with more and it explains 82.72% of variation ///
A Cronbach's alpha of 0.7154 indicates moderate underlying measure*/
 
* Assets 2
factor a2_*   [aw=W_FinSPwt], mineigen(1)
/*No factors retained*/
*rotate, varimax
factor a2_* [aw=W_FinSPwt]
predict asset2
alpha a2_*
/*Assets2 do not jointly seem to represent underlying definition of wealth with 0 egenvalues over 1 
an index was estimated with all the variables. Cronbach's alpha is 0.4188 indicating low underlying measure */

* Agriculture
*factor ag_*  [aw=W_FinSPwt], mineigen(1) 
/*No vars available*/
*rotate, varimax
*factor ag_*
*predict agri
*alpha ag_*

pwcorr all_assets dwelling asset1 asset2 [aw=W_FinSPwt] ,sig
/* Assets and secondary assets have low correlation with overall asset index */


*Dropping agriculture related
drop a2_agri 

*Dropping assets not relates to overall assets (<0.1 of factor loading, before rotation): 
drop a_airc a_bicy a_three a_elec_car  

*Dropping secondary assets not related to overall assets (<0.1 of factor loading, before rotation):
drop a2_gard

*Dropping dwelling characteristics not related to overall assets (<0.1 of factor loading, before rotation):
drop f_wood f_tile 

***** Asset Index with remaining variables *********
factor a_* a2_* r_* f_* w_* room_*  c_* to_* dw_* [aw=W_FinSPwt], mineigen(1) 
predict asset_index
alpha  a_* a2_* r_* f_* w_* room_*  c_* to_* dw_*
/* Cronbach's Alpha: 0.7593.*/

*kdensity asset_index [aw=W_FinSPwt]

 xtile asset_q=asset_index [aw=W_FinSPwt] , nq(5)
 keep asset_q  country asset_index hhn cluster W_FinSPwt
 save "$pathworkingdata/Temp.dta", replace

use "$pathworkingdata/STEP Yunnan_working.dta",clear
sort cluster hhn
merge cluster hhn using "$pathworkingdata/Temp.dta"
assert _merge==3
drop _merge
label var asset_index "Asset Wealth Index"
label var asset_q "Asset Wealth Index Quintiles"
compress
sort cluster hhn
save "$pathworkingdata/STEP Yunnan_working.dta", replace

******************************************************** END OF YUNNAN ********************************************************



****************************************************** END OF STEP DO-FILE 6 **********************************************************
