********************************************************************************************************************
* STEP | GENERATING DERIVED VARIABLES FROM THE BACKGROUND QUESTIONNAIRE & LITERACY ASSESSMENT DATA
*
*	DO-FILE 3: SKILLS AGGREGATION
*
* N. Millan's December 6, 2012 do-file
*
* Created: December 6, 2012
* Last updated: Nov 13, 2013
********************************************************************************************************************

/*
As of April 25, 2014 the STEP countries are:
	- Bolivia
	- Colombia
	- Laos
	- Sri Lanka
	- Vietnam
	- Yunnan
	- Ukraine

This do-file uses the STEP Working data files to generate aggregate variables for different type of skills (based on the household questionnaire data).

It is based on Natalia Millan's December 6, 2012 do-file.
*/

global pathworkingdata 

**************************************************************** LOOP THROUGH ALL COUNTRIES ************************************************************************

foreach country in "Bolivia" "Laos" "Sri Lanka" "Vietnam" "Yunnan" "Colombia" {
	use "$pathworkingdata/STEP `country'_working.dta", clear

	***********COGNITIVE************************************
****READING**********
	*at work
gen read_work=.
replace read_work=0 if m5a_q06==6 | m5a_q04==2 
replace read_work=1 if m5a_q06==1 | m5a_q06==2
replace read_work=2 if m5a_q06==3 | m5a_q06==4
replace read_work=3 if m5a_q06==5
	*outside work
gen read_outside=.
replace read_outside=0 if m5a_q07==6| m5a_q08==2 | m5a_q21==2| m5a_q10==6| m5a_q23==6
replace read_outside=1 if m5a_q07==1|  m5a_q07==2 |m5a_q10==1| m5a_q10==2 |m5a_q23==1 |m5a_q23==2
replace read_outside=2 if m5a_q07==3|  m5a_q07==4 |m5a_q10==3| m5a_q10==4 |m5a_q23==3 |m5a_q23==4
replace read_outside=3 if m5a_q07==5 |m5a_q10==5|m5a_q23==5

	*overall
gen read=max(read_work, read_outside)


*** WRITING***
**writing length****
	*at work
gen write_work=.
replace write_work=0 if m5a_q13==6 | m5a_q12==2 
replace write_work=1 if m5a_q13==1 | m5a_q13==2
replace write_work=2 if m5a_q13==3 | m5a_q13==4
replace write_work=3 if m5a_q13==5
	*outside work
gen write_outside=.
replace write_outside=0 if m5a_q16==2 | m5a_q25==2|m5a_q14==6| m5a_q17==6| m5a_q26==6
replace write_outside=1 if m5a_q14==1|  m5a_q14==2 |m5a_q17==1| m5a_q17==2 |m5a_q26==1 |m5a_q26==2
replace write_outside=2 if m5a_q14==3|  m5a_q14==4 |m5a_q17==3| m5a_q17==4 |m5a_q26==3 |m5a_q26==4
replace write_outside=3 if m5a_q14==5 |m5a_q17==5|m5a_q26==5
	*overall
gen write=max(write_work, write_outside)



***************************
/**SELF-REPORT NUMERACY
****************************
gen srnum=0 if m5a_q18_1~=. | m5a_q18_2~=.  | m5a_q18_3~=.  | m5a_q18_4~=. | m5a_q18_5~=.  | m5a_q18_6~=. | m5a_q19_1~=. | m5a_q19_2~=.  | m5a_q19_3~=.  | m5a_q19_4~=. | m5a_q19_5~=.  | m5a_q19_6~=. | m5a_q27_1~=. | m5a_q27_2~=.  | m5a_q27_3~=.  | m5a_q27_4~=. | m5a_q27_5~=.  | m5a_q27_6~=. 
replace srnum=1 if m5a_q18_1==1 | m5a_q18_2==1  | m5a_q18_3==1  | m5a_q18_4==1 | m5a_q18_5==1  | m5a_q18_6==1 | m5a_q19_1==1 | m5a_q19_2==1  | m5a_q19_3==1  | m5a_q19_4==1 | m5a_q19_5==1  | m5a_q19_6==1 | m5a_q27_1==1 | m5a_q27_2==1  | m5a_q27_3==1  | m5a_q27_4==1 | m5a_q27_5==1  | m5a_q27_6==1 
*/

*NUMERACY: intensity (Question 1 counts as one)
gen num_work=.
replace num_work=1 if m5a_q18_4==1 | m5a_q18_2==1 |m5a_q18_1==1
replace num_work=2 if m5a_q18_3==1 
replace num_work=3 if m5a_q18_5==1
replace num_work=0 if m5a_q18_4==2 & m5a_q18_2==2 & m5a_q18_1==2 & m5a_q18_3==2 & m5a_q18_5==2

gen num_outside=.
replace num_outside=1 if m5a_q19_4==1 | m5a_q19_2==1 |m5a_q19_1==1 |m5a_q27_4==1 | m5a_q27_2==1| m5a_q27_1==1
replace num_outside=2 if m5a_q19_3==1 | m5a_q27_3==1 
replace num_outside=3 if m5a_q19_5==1 |m5a_q27_5==1

replace num_outside=0 if m5a_q19_4==2 & m5a_q19_2==2 & m5a_q19_1==2 & m5a_q19_3==2& m5a_q19_5==2 
replace num_outside=0 if m5a_q27_4==2 & m5a_q27_2==2& m5a_q27_1==2& m5a_q27_3==2 & m5a_q27_5==2

/*FOR COLOMBIA*/
if country=="Colombia" {
	replace num_work=2 if m5a_q18_6_other=="REGLA DE TRES Y CONVERSION DE MEDIDAS" & country=="Colombia"
	replace num_work=3 if m5a_q18_6_other=="CONTABILIDAD" & country=="Colombia"
	replace num_work=3 if m5a_q18_6_other=="ESTADISTICA" & country=="Colombia"
	replace num_work=3 if m5a_q18_6_other== "FINANCIERA"  & country=="Colombia"

	replace num_outside=3 if m5a_q27_6_other=="CALCULO" & country=="Colombia"
	replace num_outside=3 if m5a_q19_6_other=="FINANCIERA" & country=="Colombia"
	replace num_outside=3 if m5a_q19_6_other=="ESTADISTICA" & country=="Colombia"
}
	
*OVERALL NUMERACY
tab num_work
tab num_outside


 /*MAKE CORRECTIONS TO NUMERACY FOR THOSE WHO ANSWER "OTHER"
 ALL OF THESE INDIVIDUALS PERFORM COMPLEX OPERATIONS (STATISTICS, ECONOMETRICS, ETC)*/
if country=="Bolivia" {
	replace num_work=3 if m5a_q18_6==1 & country=="Bolivia"
	replace num_outside=3 if m5a_q19_6==1|m5a_q27_6==1 & country=="Bolivia"
}
 /*COLOMBIA - ok*/
 /*LAOS is OK - one person uses "GPS", but this is not a numeracy skill*/
 /*VIETNAM is indecipherable*/
 /*SRI LANKA doesn't have anyone answer "other"*/
 /*Yunnan has people specifying "other" but they don't specify*/

gen num=max(num_work, num_outside)
tab num_work
tab num_outside
tab num

***********************
*****TECHNICAL*********
***********************

**interpersonal_external and internal**
gen interpers_ex=.
replace interpers_ex=0 if m5b_q04==2
replace interpers_ex=1 if m5b_q05>=1 & m5b_q05<=4
replace interpers_ex=2 if m5b_q05>=5 & m5b_q05<=7
replace interpers_ex=3 if m5b_q05>=8 & m5b_q05<=10

gen present=. 
replace present=1 if  m5b_q10==1
replace present=0 if m5b_q10==2

gen supervise=.
replace supervise=1 if m5b_q11==1
replace supervise=0 if m5b_q11==2


**use of technology
	*******************************
	*computer frequency
	*******************************
	*at work
gen comp_work=.
replace comp_work=0 if m5b_q16==2|m5b_q17==4 
replace comp_work=1 if m5b_q17==3
replace comp_work=2 if m5b_q17==2
replace comp_work=3 if m5b_q17==1

	*outside of work
gen comp_outside=.
replace comp_outside=0 if m5b_q28==2 |m5b_q29==4
replace comp_outside=1 if m5b_q29==3
replace comp_outside=2 if m5b_q29==2
replace comp_outside=3 if m5b_q29==1

	*overall
gen computer=max(comp_work, comp_outside)
	
	
* Computer Type

gen computertype=0 if m5b_q16==2
replace computertype=1 if m5b_q18_1==1 | m5b_q18_2==1 | m5b_q18_3==1| m5b_q18_4==1
replace computertype=2 if m5b_q18_5==1 | m5b_q20_1==1 | m5b_q20_2==1 | m5b_q20_3==1 | m5b_q20_4==1 | m5b_q20_5==1 | m5b_q20_6==1 | m5b_q20_7==1 | m5b_q20_8==1



**drive, repair, operate at work
gen drive=1 if m5b_q06==1
replace drive=0 if m5b_q06==2

gen repair=1 if m5b_q07==1 
replace repair=0 if m5b_q07==2

gen operate=1 if m5b_q08 ==1
replace operate=0 if m5b_q08==2


**cognitive challenge
gen think=.
replace think=0 if m5b_q09==1
replace think=1 if m5b_q09==2
replace think=2 if m5b_q09==3
replace think=2 if m5b_q09==4
replace think=3 if m5b_q09==5

gen learn=.
replace learn=0 if m5b_q15==5
replace learn=1 if m5b_q15==3
replace learn=1 if m5b_q15==4
replace learn=2 if m5b_q15==2
replace learn=3 if m5b_q15==1

gen cogchall_avg=(think+learn)/2
gen cogchall=.
replace cogchall=0 if cogchall_avg==0
replace cogchall=1 if cogchall_avg>=0.5 & cogchall_avg<=1
replace cogchall=2 if cogchall_avg>=1.5 & cogchall_avg<=2
replace cogchall=3 if cogchall_avg>=2.5 & cogchall_avg<=3

tab cogchall
**autonomy and repetitiveness
gen autonomy=.
replace autonomy=0 if m5b_q12>=1 & m5b_q12<=2
replace autonomy=1 if m5b_q12>=3 & m5b_q12<=6
replace autonomy=2 if m5b_q12>=7 & m5b_q12<=9
replace autonomy=3 if m5b_q12==10

gen repet=.
replace repet=0 if m5b_q14==1
replace repet=1 if m5b_q14==2
replace repet=2 if m5b_q14==3
replace repet=3 if m5b_q14==4

gen auto_avg=(autonomy+repet)/2
gen auto_rep=.
replace auto_rep=0 if auto_avg==0
replace auto_rep=1 if auto_avg>=0.5 & auto_avg<=1
replace auto_rep=2 if auto_avg>=1.5 & auto_avg<=2
replace auto_rep=3 if auto_avg>=2.5 & auto_avg<=3

tab auto_rep

**physical
gen physic=.
replace physic=0 if  m5b_q03==1
replace physic=1 if  m5b_q03>=2 & m5b_q03<=4
replace physic=2 if  m5b_q03>=5 & m5b_q03<=6
replace physic=3 if  m5b_q03>=7 & m5b_q03<=10


*OVERALL SKILLS-SKILLS USED AT WORK
gen read_dif=read-read_work
gen write_dif=write-read_work
gen num_dif=num-num_work
gen comp_dif=computer-comp_work
*************************************************************
*DUMMIES
********************************************************************
gen 	comp_wdummy=1 if m5b_q16==1
replace comp_wdummy=0 if m5b_q16==2

gen     comp_owdummy=1 if m5b_q28==1
replace comp_owdummy=0 if m5b_q28==2

gen		comp_dummy	=max(comp_wdummy, comp_owdummy)	

gen     read_wdummy=1 if  m5a_q04==1
replace read_wdummy=0 if m5a_q04==2
replace read_wdummy=1 if read_work>0 & read_work!=.
replace read_wdummy=0 if read_work==0

gen 	read_owdummy=0 if m5a_q07==6 		/*Question for workers who read at work*/
replace read_owdummy=1 if m5a_q07<=5
replace read_owdummy=1 if m5a_q07==9 		/*Assumes ppl who answer "don't know" to length of material do 
													read outside work*/
replace read_owdummy=1 if m5a_q08==1 		/*Question for workers who do not read at work*/
replace read_owdummy=0 if m5a_q08==2
replace read_owdummy=1 if m5a_q21==1		 /*Question for those who haven't worked in last 12 months*/
replace read_owdummy=0 if m5a_q21==2
replace read_owdummy=0 if read_outside==0

gen     write_wdummy=1 if m5a_q12 ==1
replace write_wdummy=0 if m5a_q12 ==2
replace write_wdummy=0 if write_work==0

gen     write_owdummy=1 if m5a_q14 <=5
replace write_owdummy=1 if m5a_q14 ==9  		/*Assumes ppl who answer "don't know" do write outside work*/
replace write_owdummy=0 if m5a_q14 ==6
replace write_owdummy=1 if m5a_q16 ==1
replace write_owdummy=0 if m5a_q16 ==2
replace write_owdummy=1 if m5a_q25 ==1  	    /*Haven't worked in last 12 months*/
replace write_owdummy=0 if m5a_q25 ==2
replace write_owdummy=0 if write_outside==0

gen		num_wdummy	=1 if num_work!=. & num_work!=0
replace num_wdummy=0 if num_work==0
gen		num_owdummy	=1 if num_outside!=. & num_outside!=0
replace num_owdummy=0 if num_outside==0

gen		read_dummy	=max(read_wdummy, read_owdummy)	

gen		write_dummy	=max(write_wdummy, write_owdummy)	

gen		num_dummy	=max(num_wdummy, num_owdummy)	


*Label all dummies
label 	var	comp_wdummy	"Dummy for uses computer at work"
label 	var	comp_owdummy	"Dummy for uses computer outside of work"
label 	var	comp_dummy	"Dummy for uses computer overall"
label 	var	read_wdummy	"Dummy for reads at work"
label 	var	read_owdummy	"Dummy for reads outside of work"
label 	var	write_wdummy	"Dummy for writes at work"
label 	var	write_owdummy	"Dummy for writes outside of work"
label 	var	num_wdummy	"Dummy for numeracy at work"
label 	var	num_owdummy	"Dummy for numeracy outside of work"
label 	var	read_dummy	"Dummy for reads overall"
label 	var	write_dummy	"Dummy for writes overall"
label 	var	num_dummy	"Dummy for numeracy overall"


************************
********NON-COGNITIVE***
************************
*Change all "don't knows" to missing
	foreach var of varlist   m6a_q0101- m6a_q0124 m6b_q01 m6b_q02 m6b_q03 m6b_q04 m6b_q05 m6b_q07 {
	replace `var' = . if `var'==9
	}
	foreach var of varlist   m6a_q0101- m6a_q0124 m6b_q01 m6b_q02 m6b_q03 m6b_q04 m6b_q05 m6b_q07 {
	replace `var' = . if `var'==0
	}
	replace m6b_q06=. if m6b_q06==92

*drop conscientiousness extraversion openness stability agreeableness grit decision decision hostile risk discount
**extraversion***
recode m6a_q0101 m6a_q0120 (4=1) (3=2) (2=3) (1=4), gen( m6a_q0101n m6a_q0120n)
egen extraversion_av=rowmean(m6a_q0101n m6a_q0104 m6a_q0120n)
label var extraversion_av "Extraversion (average of q01 q04 q20)"
tab extraversion_av, m

**Conscientiousness
recode  m6a_q0102 m6a_q0117 (1=4) (2=3) (3=2) (4=1), gen( m6a_q0102n m6a_q0117n )
egen conscientiousness_avg=rowmean(m6a_q0102n m6a_q0112 m6a_q0117n)
label var conscientiousness_av "Conscientiousness (average of q02 q12 q17)"
tab conscientiousness_av, m

**Openness
recode  m6a_q0103 m6a_q0111 m6a_q0114 (1=4) (2=3) (3=2) (4=1), gen ( m6a_q0103n m6a_q0111n m6a_q0114n)
egen openness_av=rowmean(m6a_q0103n m6a_q0111n m6a_q0114n)
label var openness_av "Openness (average of q03 q11 q14)"
tab openness_av, m


**Emotional stability
recode  m6a_q0105 (1=4) (2=3) (3=2) (4=1), gen (m6a_q0105n)
egen stability_av=rowmean(m6a_q0105n m6a_q0110 m6a_q0118)
label var stability_av "Emotional Stability (average of q05 q10 q18)"
tab stability_av, m


**Agreeableness
recode m6a_q0109 m6a_q0116 m6a_q0119 (1=4) (2=3) (3=2) (4=1), gen(m6a_q0109n m6a_q0116n m6a_q0119n)
egen agreeableness_av=rowmean(m6a_q0109n m6a_q0116n m6a_q0119n)
label var agreeableness_av "Agreeableness (average of q09 q16 q19)"
tab agreeableness_av,m

**Grit
recode m6a_q0106 m6a_q0108 m6a_q0113 (1=4) (2=3) (3=2) (4=1), gen (m6a_q0106n m6a_q0108n m6a_q0113n)
egen grit_av=rowmean(m6a_q0106n m6a_q0108n m6a_q0113n)
label var grit_av "Grit (average of q06 q08 q13)"
tab grit_av, m 

**Decision making
recode  m6a_q0115 m6a_q0121 m6a_q0123 m6a_q0124 (1=4) (2=3) (3=2) (4=1), gen(m6a_q0115n m6a_q0121n m6a_q0123n m6a_q0124n)
egen decision_av=rowmean(m6a_q0115n m6a_q0121n m6a_q0123n m6a_q0124n)
label var decision_av "Decision making (average of q15 q21 q23 q24)"
tab decision_av, m

**Hostile: 4- more likely to perceive people to be mean
recode m6a_q0107 m6a_q0122 (1=4) (2=3) (3=2) (4=1), gen(m6a_q0107n m6a_q0122n)
egen hostile_av=rowmean(m6a_q0107n m6a_q0122n)
label var hostile_av "Hostile Bias (average of q07 q22)"
tab hostile, m


**RISK AVERSION
gen risk=1 if m6b_q01==1 & m6b_q02==1
replace risk=2 if m6b_q01==1 & m6b_q02==2
replace risk=3 if m6b_q01==2 & m6b_q03==1
replace risk=4 if m6b_q01==2 & m6b_q03==2
label var risk  "Risk aversion" 

**discount
gen discount=1 if m6b_q04==1 & m6b_q05==1
replace discount=2 if m6b_q04==1 & m6b_q05==2
replace discount=3 if m6b_q04==2 & m6b_q07==1
replace discount=4 if m6b_q04==2 & m6b_q07==2
label var discount "Time preference" 

* NOTE ON COLOMBIA: ERROR IN THE QUESTIONNAIRE	-> discount variable must be recoded to 'missing'
if country=="Colombia" {
	replace discount=.
}

tab risk 
tab discount


drop m6a_q0101n m6a_q0120n m6a_q0102n m6a_q0117n m6a_q0103n m6a_q0111n m6a_q0114n m6a_q0105n m6a_q0109n m6a_q0116n m6a_q0119n m6a_q0106n m6a_q0108n m6a_q0113n m6a_q0115n m6a_q0121n m6a_q0123n m6a_q0124n m6a_q0107n m6a_q0122n

*LABEL VARIABLES
label 	var	read_work	"Length of material read at work score"
label 	var	read_outside	"Length of material read outside of work score"
label 	var	read	"Length of material read overall score"
label 	var	write_work	"Length of material written at work score"
label 	var	write_outside	"Length of material written outside of work score"
label 	var	write	"Length of material written overall score"
label 	var	num_work	"Numeracy at work score"
label 	var	num_outside	"Numeracy outside of work score"
label 	var	num	"Numeracy overall score"
label 	var	interpers_ex	"Contact with people outside of work score"
label 	var	present	"Makes presentations at work"
label 	var	supervise	"Supervises others at work"
label 	var	comp_work	"Frequency of computer use at work score"
label 	var	comp_outside	"Frequency of computer use outside of work score"
label 	var	computer	"Frequency of computer use overall score"
label 	var	computertype	"Type of software use at work score"
label 	var	drive	"Drives a vehicle at work"
label 	var	repair	"Repairs or maintains electronic equipment at work" 
label 	var	operate	"Operates heavy machinery or industrial equipment at work"
label 	var	think	"Frequency of tasks involving at least 30 minutes of thinking score"
label 	var	learn	"Frequency of work requiring learning new things score"
label 	var	cogchall_avg	"Average of frequency of thinking and learning tasks scores"
label 	var	cogchall	"Frequency of thinking and learning new things score"
label 	var	autonomy	"Autonomy at work score"
label 	var	repet	"Repetitiveness at work score"
label 	var	auto_avg	"Average of autonomy and repetitiveness at work scores"
label 	var	auto_rep	"Autonomy and repetitiveness at work score"
label 	var	physic	"Lift heavy items at work score"
label 	var	read_dif	"Difference between overall reading and reading at work score"
label 	var	write_dif	"Difference between overall writing and writing at work score"
label 	var	num_dif	"Difference between overall numeracy and numeracy at work score"
label 	var	comp_dif	"Difference between overall computer use and computer use at work score"

label define intensity 0 "skill not used" 1 "low" 2 "medium" 3 "high"
foreach var of varlist read_work read_outside read write_work write_outside write num_work num_outside num comp_work comp_outside computer {
	lab values `var' intensity
}
	
	compress
	sort cluster hhn
	save "$pathworkingdata/STEP `country'_working.dta", replace
}


** THE STRUCTURE OF THE DATA FILES WAS SLIGTHLY DIFFERENT FOR UKRAINE
use "$pathworkingdata/STEP Ukraine_working.dta", clear

	***********COGNITIVE************************************
****READING**********
	*at work
gen read_work=.
replace read_work=0 if m5a_q06==6 | m5a_q04==2 
replace read_work=1 if m5a_q06==1 | m5a_q06==2
replace read_work=2 if m5a_q06==3 | m5a_q06==4
replace read_work=3 if m5a_q06==5
	*outside work
gen read_outside=.
replace read_outside=0 if m5a_q07==6| m5a_q08==2 | m5a_q21==2| m5a_q10==6| m5a_q23==6
replace read_outside=1 if m5a_q07==1|  m5a_q07==2 |m5a_q10==1| m5a_q10==2 |m5a_q23==1 |m5a_q23==2
replace read_outside=2 if m5a_q07==3|  m5a_q07==4 |m5a_q10==3| m5a_q10==4 |m5a_q23==3 |m5a_q23==4
replace read_outside=3 if m5a_q07==5 |m5a_q10==5|m5a_q23==5

	*overall
gen read=max(read_work, read_outside)


*** WRITING***
**writing length****
	*at work
gen write_work=.
replace write_work=0 if m5a_q13==6 | m5a_q12==2 
replace write_work=1 if m5a_q13==1 | m5a_q13==2
replace write_work=2 if m5a_q13==3 | m5a_q13==4
replace write_work=3 if m5a_q13==5
	*outside work
gen write_outside=.
replace write_outside=0 if m5a_q16==2 | m5a_q25==2|m5a_q14==6| m5a_q17==6| m5a_q26==6
replace write_outside=1 if m5a_q14==1|  m5a_q14==2 |m5a_q17==1| m5a_q17==2 |m5a_q26==1 |m5a_q26==2
replace write_outside=2 if m5a_q14==3|  m5a_q14==4 |m5a_q17==3| m5a_q17==4 |m5a_q26==3 |m5a_q26==4
replace write_outside=3 if m5a_q14==5 |m5a_q17==5|m5a_q26==5
	*overall
gen write=max(write_work, write_outside)


***************************
**SELF-REPORT NUMERACY
****************************

*NUMERACY: intensity (Question 1 counts as one)
gen num_work=.
replace num_work=1 if m5a_q18_4==1 | m5a_q18_2==1 |m5a_q18_1==1
replace num_work=2 if m5a_q18_3==1 
replace num_work=3 if m5a_q18_5==1
replace num_work=0 if m5a_q18_4==2 & m5a_q18_2==2 & m5a_q18_1==2 & m5a_q18_3==2 & m5a_q18_5==2

gen num_outside=.
replace num_outside=1 if m5a_q19_4==1 | m5a_q19_2==1 |m5a_q19_1==1 |m5a_q27_4==1 | m5a_q27_2==1| m5a_q27_1==1
replace num_outside=2 if m5a_q19_3==1 | m5a_q27_3==1 
replace num_outside=3 if m5a_q19_5==1 |m5a_q27_5==1

replace num_outside=0 if m5a_q19_4==2 & m5a_q19_2==2 & m5a_q19_1==2 & m5a_q19_3==2& m5a_q19_5==2 
replace num_outside=0 if m5a_q27_4==2 & m5a_q27_2==2& m5a_q27_1==2& m5a_q27_3==2 & m5a_q27_5==2

	
*OVERALL NUMERACY
tab num_work
tab num_outside

 /*MAKE CORRECTIONS TO NUMERACY FOR THOSE WHO ANSWER "OTHER"
 ALL OF THESE INDIVIDUALS PERFORM COMPLEX OPERATIONS (STATISTICS, ECONOMETRICS, ETC)*/
gen num=max(num_work, num_outside)
tab num_work
tab num_outside
tab num

***********************
*****TECHNICAL*********
***********************

**interpersonal_external and internal**
gen interpers_ex=.
replace interpers_ex=0 if m5b_q04==2
replace interpers_ex=1 if m5b_q05>=1 & m5b_q05<=4
replace interpers_ex=2 if m5b_q05>=5 & m5b_q05<=7
replace interpers_ex=3 if m5b_q05>=8 & m5b_q05<=10

gen present=. 
replace present=1 if  m5b_q10==1
replace present=0 if m5b_q10==2

gen supervise=.
replace supervise=1 if m5b_q11==1
replace supervise=0 if m5b_q11==2


**use of technology
	*******************************
	*computer frequency
	*******************************
	*at work
gen comp_work=.
replace comp_work=0 if m5b_q16==2|m5b_q17==4 
replace comp_work=1 if m5b_q17==3
replace comp_work=2 if m5b_q17==2
replace comp_work=3 if m5b_q17==1

	*outside of work
gen comp_outside=.
replace comp_outside=0 if m5b_q28==2 |m5b_q29==4
replace comp_outside=1 if m5b_q29==3
replace comp_outside=2 if m5b_q29==2
replace comp_outside=3 if m5b_q29==1

	*overall
gen computer=max(comp_work, comp_outside)
	
	
* Computer Type
gen computertype=0 if m5b_q16==2
replace computertype=1 if m5b_q18_1==1 | m5b_q18_2==1 | m5b_q18_3==1| m5b_q18_4==1
replace computertype=2 if m5b_q18_5==1 | m5b_q20_1==1 | m5b_q20_2==1 | m5b_q20_3==1 | m5b_q20_4==1 | m5b_q20_5==1 | m5b_q20_6==1 | m5b_q20_7==1 | m5b_q20_8==1


**drive, repair, operate at work
gen drive=1 if m5b_q06==1
replace drive=0 if m5b_q06==2

gen repair=1 if m5b_q07==1 
replace repair=0 if m5b_q07==2

gen operate=1 if m5b_q08 ==1
replace operate=0 if m5b_q08==2


**cognitive challenge
gen think=.
replace think=0 if m5b_q09==1
replace think=1 if m5b_q09==2
replace think=2 if m5b_q09==3
replace think=2 if m5b_q09==4
replace think=3 if m5b_q09==5

gen learn=.
replace learn=0 if m5b_q15==5
replace learn=1 if m5b_q15==3
replace learn=1 if m5b_q15==4
replace learn=2 if m5b_q15==2
replace learn=3 if m5b_q15==1

gen cogchall_avg=(think+learn)/2
gen cogchall=.
replace cogchall=0 if cogchall_avg==0
replace cogchall=1 if cogchall_avg>=0.5 & cogchall_avg<=1
replace cogchall=2 if cogchall_avg>=1.5 & cogchall_avg<=2
replace cogchall=3 if cogchall_avg>=2.5 & cogchall_avg<=3

tab cogchall

**autonomy and repetitiveness
gen autonomy=.
replace autonomy=0 if m5b_q12>=1 & m5b_q12<=2
replace autonomy=1 if m5b_q12>=3 & m5b_q12<=6
replace autonomy=2 if m5b_q12>=7 & m5b_q12<=9
replace autonomy=3 if m5b_q12==10

gen repet=.
replace repet=0 if m5b_q14==1
replace repet=1 if m5b_q14==2
replace repet=2 if m5b_q14==3
replace repet=3 if m5b_q14==4

gen auto_avg=(autonomy+repet)/2
gen auto_rep=.
replace auto_rep=0 if auto_avg==0
replace auto_rep=1 if auto_avg>=0.5 & auto_avg<=1
replace auto_rep=2 if auto_avg>=1.5 & auto_avg<=2
replace auto_rep=3 if auto_avg>=2.5 & auto_avg<=3

tab auto_rep

**physical
gen physic=.
replace physic=0 if  m5b_q03==1
replace physic=1 if  m5b_q03>=2 & m5b_q03<=4
replace physic=2 if  m5b_q03>=5 & m5b_q03<=6
replace physic=3 if  m5b_q03>=7 & m5b_q03<=10


*OVERALL SKILLS-SKILLS USED AT WORK
gen read_dif=read-read_work
gen write_dif=write-read_work
gen num_dif=num-num_work
gen comp_dif=computer-comp_work
*************************************************************
*DUMMIES
********************************************************************
gen 	comp_wdummy=1 if m5b_q16==1
replace comp_wdummy=0 if m5b_q16==2

gen     comp_owdummy=1 if m5b_q28==1
replace comp_owdummy=0 if m5b_q28==2

gen		comp_dummy	=max(comp_wdummy, comp_owdummy)	

gen     read_wdummy=1 if  m5a_q04==1
replace read_wdummy=0 if m5a_q04==2
replace read_wdummy=1 if read_work>0 & read_work!=.
replace read_wdummy=0 if read_work==0

gen 	read_owdummy=0 if m5a_q07==6 		/*Question for workers who read at work*/
replace read_owdummy=1 if m5a_q07<=5
replace read_owdummy=1 if m5a_q07==9 		/*Assumes ppl who answer "don't know" to length of material do 
													read outside work*/
replace read_owdummy=1 if m5a_q08==1 		/*Question for workers who do not read at work*/
replace read_owdummy=0 if m5a_q08==2
replace read_owdummy=1 if m5a_q21==1		 /*Question for those who haven't worked in last 12 months*/
replace read_owdummy=0 if m5a_q21==2
replace read_owdummy=0 if read_outside==0

gen     write_wdummy=1 if m5a_q12 ==1
replace write_wdummy=0 if m5a_q12 ==2
replace write_wdummy=0 if write_work==0

gen     write_owdummy=1 if m5a_q14 <=5
replace write_owdummy=1 if m5a_q14 ==9  		/*Assumes ppl who answer "don't know" do write outside work*/
replace write_owdummy=0 if m5a_q14 ==6
replace write_owdummy=1 if m5a_q16 ==1
replace write_owdummy=0 if m5a_q16 ==2
replace write_owdummy=1 if m5a_q25 ==1  	    /*Haven't worked in last 12 months*/
replace write_owdummy=0 if m5a_q25 ==2
replace write_owdummy=0 if write_outside==0

gen		num_wdummy	=1 if num_work!=. & num_work!=0
replace num_wdummy=0 if num_work==0
gen		num_owdummy	=1 if num_outside!=. & num_outside!=0
replace num_owdummy=0 if num_outside==0

gen		read_dummy	=max(read_wdummy, read_owdummy)	

gen		write_dummy	=max(write_wdummy, write_owdummy)	

gen		num_dummy	=max(num_wdummy, num_owdummy)	


*Label all dummies
label 	var	comp_wdummy	"Dummy for uses computer at work"
label 	var	comp_owdummy	"Dummy for uses computer outside of work"
label 	var	comp_dummy	"Dummy for uses computer overall"
label 	var	read_wdummy	"Dummy for reads at work"
label 	var	read_owdummy	"Dummy for reads outside of work"
label 	var	write_wdummy	"Dummy for writes at work"
label 	var	write_owdummy	"Dummy for writes outside of work"
label 	var	num_wdummy	"Dummy for numeracy at work"
label 	var	num_owdummy	"Dummy for numeracy outside of work"
label 	var	read_dummy	"Dummy for reads overall"
label 	var	write_dummy	"Dummy for writes overall"
label 	var	num_dummy	"Dummy for numeracy overall"


************************
********NON-COGNITIVE***
************************
*Change all "don't knows" to missing
	foreach var of varlist   m6a_q0101- m6a_q0124 m6b_q01 m6b_q02 m6b_q03 m6b_q04 m6b_q05 m6b_q07 {
	replace `var' = . if `var'==9
	}
	foreach var of varlist   m6a_q0101- m6a_q0124 m6b_q01 m6b_q02 m6b_q03 m6b_q04 m6b_q05 m6b_q07 {
	replace `var' = . if `var'==0
	}
	replace m6b_q06=. if m6b_q06==92

*drop conscientiousness extraversion openness stability agreeableness grit decision decision hostile risk discount
**extraversion***
recode m6a_q0101 m6a_q0120 (4=1) (3=2) (2=3) (1=4), gen( m6a_q0101n m6a_q0120n)
egen extraversion_av=rowmean(m6a_q0101n m6a_q0104 m6a_q0120n)
label var extraversion_av "Extraversion (average of q01 q04 q20)"
tab extraversion_av, m

**Conscientiousness
recode  m6a_q0102 m6a_q0117 (1=4) (2=3) (3=2) (4=1), gen( m6a_q0102n m6a_q0117n )
egen conscientiousness_avg=rowmean(m6a_q0102n m6a_q0112 m6a_q0117n)
label var conscientiousness_av "Conscientiousness (average of q02 q12 q17)"
tab conscientiousness_av, m

**Openness
recode  m6a_q0103 m6a_q0111 m6a_q0114 (1=4) (2=3) (3=2) (4=1), gen ( m6a_q0103n m6a_q0111n m6a_q0114n)
egen openness_av=rowmean(m6a_q0103n m6a_q0111n m6a_q0114n)
label var openness_av "Openness (average of q03 q11 q14)"
tab openness_av, m


**Emotional stability
recode  m6a_q0105 (1=4) (2=3) (3=2) (4=1), gen (m6a_q0105n)
egen stability_av=rowmean(m6a_q0105n m6a_q0110 m6a_q0118)
label var stability_av "Emotional Stability (average of q05 q10 q18)"
tab stability_av, m


**Agreeableness
recode m6a_q0109 m6a_q0116 m6a_q0119 (1=4) (2=3) (3=2) (4=1), gen(m6a_q0109n m6a_q0116n m6a_q0119n)
egen agreeableness_av=rowmean(m6a_q0109n m6a_q0116n m6a_q0119n)
label var agreeableness_av "Agreeableness (average of q09 q16 q19)"
tab agreeableness_av,m

**Grit
recode m6a_q0106 m6a_q0108 m6a_q0113 (1=4) (2=3) (3=2) (4=1), gen (m6a_q0106n m6a_q0108n m6a_q0113n)
egen grit_av=rowmean(m6a_q0106n m6a_q0108n m6a_q0113n)
label var grit_av "Grit (average of q06 q08 q13)"
tab grit_av, m 

**Decision making
recode  m6a_q0115 m6a_q0121 m6a_q0123 m6a_q0124 (1=4) (2=3) (3=2) (4=1), gen(m6a_q0115n m6a_q0121n m6a_q0123n m6a_q0124n)
egen decision_av=rowmean(m6a_q0115n m6a_q0121n m6a_q0123n m6a_q0124n)
label var decision_av "Decision making (average of q15 q21 q23 q24)"
tab decision_av, m

**Hostile: 4- more likely to perceive people to be mean
recode m6a_q0107 m6a_q0122 (1=4) (2=3) (3=2) (4=1), gen(m6a_q0107n m6a_q0122n)
egen hostile_av=rowmean(m6a_q0107n m6a_q0122n)
label var hostile_av "Hostile Bias (average of q07 q22)"
tab hostile, m

**RISK AVERSION
gen risk=1 if m6b_q01==1 & m6b_q02==1
replace risk=2 if m6b_q01==1 & m6b_q02==2
replace risk=3 if m6b_q01==2 & m6b_q03==1
replace risk=4 if m6b_q01==2 & m6b_q03==2
label var risk  "Risk aversion" 

**discount
gen discount=1 if m6b_q04==1 & m6b_q05==1
replace discount=2 if m6b_q04==1 & m6b_q05==2
replace discount=3 if m6b_q04==2 & m6b_q07==1
replace discount=4 if m6b_q04==2 & m6b_q07==2
label var discount "Time preference" 

tab risk 
tab discount

drop m6a_q0101n m6a_q0120n m6a_q0102n m6a_q0117n m6a_q0103n m6a_q0111n m6a_q0114n m6a_q0105n m6a_q0109n m6a_q0116n m6a_q0119n m6a_q0106n m6a_q0108n m6a_q0113n m6a_q0115n m6a_q0121n m6a_q0123n m6a_q0124n m6a_q0107n m6a_q0122n

*LABEL VARIABLES
label 	var	read_work	"Length of material read at work score"
label 	var	read_outside	"Length of material read outside of work score"
label 	var	read	"Length of material read overall score"
label 	var	write_work	"Length of material written at work score"
label 	var	write_outside	"Length of material written outside of work score"
label 	var	write	"Length of material written overall score"
label 	var	num_work	"Numeracy at work score"
label 	var	num_outside	"Numeracy outside of work score"
label 	var	num	"Numeracy overall score"
label 	var	interpers_ex	"Contact with people outside of work score"
label 	var	present	"Makes presentations at work"
label 	var	supervise	"Supervises others at work"
label 	var	comp_work	"Frequency of computer use at work score"
label 	var	comp_outside	"Frequency of computer use outside of work score"
label 	var	computer	"Frequency of computer use overall score"
label 	var	computertype	"Type of software use at work score"
label 	var	drive	"Drives a vehicle at work"
label 	var	repair	"Repairs or maintains electronic equipment at work" 
label 	var	operate	"Operates heavy machinery or industrial equipment at work"
label 	var	think	"Frequency of tasks involving at least 30 minutes of thinking score"
label 	var	learn	"Frequency of work requiring learning new things score"
label 	var	cogchall_avg	"Average of frequency of thinking and learning tasks scores"
label 	var	cogchall	"Frequency of thinking and learning new things score"
label 	var	autonomy	"Autonomy at work score"
label 	var	repet	"Repetitiveness at work score"
label 	var	auto_avg	"Average of autonomy and repetitiveness at work scores"
label 	var	auto_rep	"Autonomy and repetitiveness at work score"
label 	var	physic	"Lift heavy items at work score"
label 	var	read_dif	"Difference between overall reading and reading at work score"
label 	var	write_dif	"Difference between overall writing and writing at work score"
label 	var	num_dif	"Difference between overall numeracy and numeracy at work score"
label 	var	comp_dif	"Difference between overall computer use and computer use at work score"

label define intensity 0 "skill not used" 1 "low" 2 "medium" 3 "high"
foreach var of varlist read_work read_outside read write_work write_outside write num_work num_outside num comp_work comp_outside computer {
	lab values `var' intensity
}
	
compress
sort cluster hhn
	
save "$pathworkingdata/STEP Ukraine_working.dta", replace



**************************************************************************** END OF STEP DO-FILE 3 ******************************************************************
